import React from "react";
import { UI } from "../UI";
import { useProps } from "../contexts";
import { MonthsDropdown } from "./MonthsDropdown";
import { YearsDropdown } from "./YearsDropdown";
/**
 * Render the dropdowns to navigate between months.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://daypicker.dev/advanced-guides/custom-components
 */
export function DropdownNav(props) {
    const { classNames, styles, formatters: { formatMonthDropdown, formatYearDropdown } } = useProps();
    return (React.createElement("div", { className: classNames[UI.DropdownNav], style: styles?.[UI.DropdownNav] },
        props.showMonths ? (React.createElement(MonthsDropdown, { month: props.month })) : (React.createElement("span", { role: "status", "aria-live": "polite" }, formatMonthDropdown(props.month.date.getMonth()))),
        props.showYears ? (React.createElement(YearsDropdown, { month: props.month })) : (React.createElement("span", { role: "status", "aria-live": "polite" }, formatYearDropdown(props.month.date.getFullYear())))));
}
//# sourceMappingURL=DropdownNav.js.map