import React from "react";
import { useProps } from "../contexts";
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const SingleContext = React.createContext(undefined);
function useSingleContextValue({ required = false, selected, onSelect }) {
    const [date, setDate] = React.useState(selected);
    const { dateLib: { isSameDay }, today, mode } = useProps();
    // Update the selected date if the required flag is set.
    React.useEffect(() => {
        if (required && date === undefined) {
            setDate(today);
        }
    }, [required, date, today]);
    // Update the selected date if the `selected` value changes.
    React.useEffect(() => {
        if (mode !== "single")
            return;
        setDate(selected);
    }, [mode, selected]);
    const isSelected = (compareDate) => {
        return date ? isSameDay(date, compareDate) : false;
    };
    const setSelected = (triggerDate, modifiers, e) => {
        let newDate = triggerDate;
        if (!required && date && date && isSameDay(triggerDate, date)) {
            // If the date is the same, clear the selection.
            newDate = undefined;
        }
        setDate(newDate);
        onSelect?.(newDate, triggerDate, modifiers, e);
        return newDate;
    };
    return { selected: date, setSelected, isSelected };
}
/** @private */
export function SingleProvider(props) {
    const value = useSingleContextValue(props);
    return (React.createElement(SingleContext.Provider, { value: value }, props.children));
}
/**
 * Access to the single context to get the selected date or update it.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://daypicker.dev/advanced-guides/custom-components
 */
export function useSingle() {
    const context = React.useContext(SingleContext);
    if (!context) {
        throw new Error("useSingle() must be used within a SingleContextProvider");
    }
    return context;
}
//# sourceMappingURL=useSingle.js.map